==> artemis_cupps-0.0.59.tar.gz: lib/constants.dart <==
class CuppsMessageID {
  CuppsMessageID._();

  static const String interfaceLevelsAvailable =
      "interfaceLevelsAvailableResponse";
  static const String interfaceLevel = "interfaceLevelResponse";
  static const String authenticate = "authenticateResponse";
  static const String interfaceMode = "interfaceModeResponse";
  static const String deviceAcquire = "deviceAcquireResponse";
  static const String deviceReleaseResponse = "deviceReleaseResponse";
  static const String deviceStatus = "deviceStatusResponse";
  static const String aeaResponse = "aeaResponse";
  static const String aeaRequest = "aeaRequest";
  static const String deviceLockResponse = "deviceLockResponse";
  static const String deviceUnlockResponse = "deviceUnlockResponse";
  static const String readerReadResponse = "readerReadResponse";
  static const String applicationStopCommandResponse = "applicationStopCommandResponseResponse";
  static const String applicationStopCommandRequest = "applicationStopCommandResponseRequest";
  static const String bye = "byeResponse";
  static const String notify = "notify";
}

class AssetImages {
  AssetImages._();

  static const assetsAddress = 'assets/images';

  static const iconsAddress = '$assetsAddress/icons';

  static const bgIconsAddress = '$iconsAddress/bg';
  static const bgIconsAddressActive = '$bgIconsAddress/bg_active.png';
  static const bgIconsAddressDisconnect = '$bgIconsAddress/bg_disconnect.png';
  static const bgIconsAddressIn = '$bgIconsAddress/bg_in.png';
  static const bgIconsAddressNatural = '$bgIconsAddress/bg_natural.png';
  static const bgIconsAddressDataAvailable = '$bgIconsAddress/bg_data_available.png';

  static const bpIconsAddress = '$iconsAddress/bp';
  static const bpIconsAddressActive = '$bpIconsAddress/bp_active.png';
  static const bpIconsAddressDisconnect = '$bpIconsAddress/bp_disconnect.png';
  static const bpIconsAddressIn = '$bpIconsAddress/bp_in.png';
  static const bpIconsAddressNatural = '$bpIconsAddress/bp_natural.png';
  static const bpIconsAddressJammed = '$bpIconsAddress/bp_jammed.png';
  static const bpIconsAddressOpen = '$bpIconsAddress/bp_open.png';
  static const bpIconsAddressPaperOut = '$bpIconsAddress/bp_paper_out.png';

  static const bcIconsAddress = '$iconsAddress/bc';
  static const bcIconsAddressActive = '$bcIconsAddress/bc_active.png';
  static const bcIconsAddressDisconnect = '$bcIconsAddress/bc_disconnect.png';
  static const bcIconsAddressIn = '$bcIconsAddress/bc_in.png';
  static const bcIconsAddressNatural = '$bcIconsAddress/bc_natural.png';
  static const bcIconsAddressLocked = '$bcIconsAddress/bc_locked.png';
  static const bcIconsAddressDataAvailable = '$bcIconsAddress/bc_data_available.png';


  static const btIconsAddress = '$iconsAddress/bt';
  static const btIconsAddressActive = '$btIconsAddress/bt_active.png';
  static const btIconsAddressDisconnect = '$btIconsAddress/bt_disconnect.png';
  static const btIconsAddressIn = '$btIconsAddress/bt_in.png';
  static const btIconsAddressNatural = '$btIconsAddress/bt_natural.png';
  static const btIconsAddressJammed = '$btIconsAddress/bt_jammed.png';
  static const btIconsAddressOpen = '$btIconsAddress/bt_open.png';
  static const btIconsAddressPaperOut = '$btIconsAddress/bt_paper_out.png';


  static const msIconsAddress = '$iconsAddress/ms';
  static const msIconsAddressActive = '$msIconsAddress/ms_active.png';
  static const msIconsAddressDisconnect = '$msIconsAddress/ms_disconnect.png';
  static const msIconsAddressIn = '$msIconsAddress/ms_in.png';
  static const msIconsAddressNatural = '$msIconsAddress/ms_natural.png';
  static const msIconsAddressLocked = '$msIconsAddress/ms_locked.png';
  static const msIconsAddressDataAvailable = '$msIconsAddress/ms_data_available.png';

  static const ocIconsAddress = '$iconsAddress/oc';
  static const ocIconsAddressActive = '$ocIconsAddress/oc_active.png';
  static const ocIconsAddressDisconnect = '$ocIconsAddress/oc_disconnect.png';
  static const ocIconsAddressIn = '$ocIconsAddress/oc_in.png';
  static const ocIconsAddressNatural = '$ocIconsAddress/oc_natural.png';
  static const ocIconsAddressLocked = '$ocIconsAddress/oc_locked.png';
  static const ocIconsAddressDataAvailable = '$ocIconsAddress/oc_data_available.png';


  static const prIconsAddress = '$iconsAddress/pr';
  static const prIconsAddressActive = '$prIconsAddress/pr_active.png';
  static const prIconsAddressDisconnect = '$prIconsAddress/pr_disconnect.png';
  static const prIconsAddressIn = '$prIconsAddress/pr_in.png';
  static const prIconsAddressNatural = '$prIconsAddress/pr_natural.png';
  static const prIconsAddressLocked = '$prIconsAddress/pr_locked.png';

  static const unknownDevice = '$iconsAddress/unknown.png';
}

==> artemis_cupps-0.0.83.tar.gz: lib/constants.dart <==
class CuppsMessageID {
  CuppsMessageID._();

  static const String interfaceLevelsAvailable =
      "interfaceLevelsAvailableResponse";
  static const String interfaceLevel = "interfaceLevelResponse";
  static const String authenticate = "authenticateResponse";
  static const String interfaceMode = "interfaceModeResponse";
  static const String deviceAcquire = "deviceAcquireResponse";
  static const String deviceReleaseResponse = "deviceReleaseResponse";
  static const String deviceStatus = "deviceStatusResponse";
  static const String aeaResponse = "aeaResponse";
  static const String aeaRequest = "aeaRequest";
  static const String deviceLockResponse = "deviceLockResponse";
  static const String deviceUnlockResponse = "deviceUnlockResponse";
  static const String readerReadResponse = "readerReadResponse";
  static const String applicationStopCommandResponse = "applicationStopCommandResponse";
  static const String applicationStopCommandRequest = "applicationStopCommandRequest";
  static const String bye = "byeResponse";
  static const String notify = "notify";
}

class AssetImages {
  AssetImages._();

  static const assetsAddress = 'assets/images';

  static const iconsAddress = '$assetsAddress/icons';

  static const bgIconsAddress = '$iconsAddress/bg';
  static const bgIconsAddressActive = '$bgIconsAddress/bg_active.png';
  static const bgIconsAddressDisconnect = '$bgIconsAddress/bg_disconnect.png';
  static const bgIconsAddressIn = '$bgIconsAddress/bg_in.png';
  static const bgIconsAddressNatural = '$bgIconsAddress/bg_natural.png';
  static const bgIconsAddressDataAvailable = '$bgIconsAddress/bg_data_available.png';

  static const bpIconsAddress = '$iconsAddress/bp';
  static const bpIconsAddressActive = '$bpIconsAddress/bp_active.png';
  static const bpIconsAddressDisconnect = '$bpIconsAddress/bp_disconnect.png';
  static const bpIconsAddressIn = '$bpIconsAddress/bp_in.png';
  static const bpIconsAddressNatural = '$bpIconsAddress/bp_natural.png';
  static const bpIconsAddressJammed = '$bpIconsAddress/bp_jammed.png';
  static const bpIconsAddressOpen = '$bpIconsAddress/bp_open.png';
  static const bpIconsAddressPaperOut = '$bpIconsAddress/bp_paper_out.png';

  static const bcIconsAddress = '$iconsAddress/bc';
  static const bcIconsAddressActive = '$bcIconsAddress/bc_active.png';
  static const bcIconsAddressDisconnect = '$bcIconsAddress/bc_disconnect.png';
  static const bcIconsAddressIn = '$bcIconsAddress/bc_in.png';
  static const bcIconsAddressNatural = '$bcIconsAddress/bc_natural.png';
  static const bcIconsAddressLocked = '$bcIconsAddress/bc_locked.png';
  static const bcIconsAddressDataAvailable = '$bcIconsAddress/bc_data_available.png';


  static const btIconsAddress = '$iconsAddress/bt';
  static const btIconsAddressActive = '$btIconsAddress/bt_active.png';
  static const btIconsAddressDisconnect = '$btIconsAddress/bt_disconnect.png';
  static const btIconsAddressIn = '$btIconsAddress/bt_in.png';
  static const btIconsAddressNatural = '$btIconsAddress/bt_natural.png';
  static const btIconsAddressJammed = '$btIconsAddress/bt_jammed.png';
  static const btIconsAddressOpen = '$btIconsAddress/bt_open.png';
  static const btIconsAddressPaperOut = '$btIconsAddress/bt_paper_out.png';


  static const msIconsAddress = '$iconsAddress/ms';
  static const msIconsAddressActive = '$msIconsAddress/ms_active.png';
  static const msIconsAddressDisconnect = '$msIconsAddress/ms_disconnect.png';
  static const msIconsAddressIn = '$msIconsAddress/ms_in.png';
  static const msIconsAddressNatural = '$msIconsAddress/ms_natural.png';
  static const msIconsAddressLocked = '$msIconsAddress/ms_locked.png';
  static const msIconsAddressDataAvailable = '$msIconsAddress/ms_data_available.png';

  static const ocIconsAddress = '$iconsAddress/oc';
  static const ocIconsAddressActive = '$ocIconsAddress/oc_active.png';
  static const ocIconsAddressDisconnect = '$ocIconsAddress/oc_disconnect.png';
  static const ocIconsAddressIn = '$ocIconsAddress/oc_in.png';
  static const ocIconsAddressNatural = '$ocIconsAddress/oc_natural.png';
  static const ocIconsAddressLocked = '$ocIconsAddress/oc_locked.png';
  static const ocIconsAddressDataAvailable = '$ocIconsAddress/oc_data_available.png';


  static const prIconsAddress = '$iconsAddress/pr';
  static const prIconsAddressActive = '$prIconsAddress/pr_active.png';
  static const prIconsAddressDisconnect = '$prIconsAddress/pr_disconnect.png';
  static const prIconsAddressIn = '$prIconsAddress/pr_in.png';
  static const prIconsAddressNatural = '$prIconsAddress/pr_natural.png';
  static const prIconsAddressLocked = '$prIconsAddress/pr_locked.png';

  static const unknownDevice = '$iconsAddress/unknown.png';
}
